@@ -1,4 +1,3 @@
-import string
 import re
 
 Zero = "PyUFunc_Zero"
@@ -101,6 +100,7 @@ allM = bints+flts+cmplxM
 nobool = all[1:]
 nobool_or_obj = all[1:-1]
 intflt = ints+flts
+intfltcmplx = nobool_or_obj
 nocmplx = bints+flts
 nocmplxO = nocmplx+O
 nocmplxM = nocmplx+M
@@ -122,22 +122,19 @@ defdict = {
 'multiply' :
     Ufunc(2, 1, One,
           'multiplies the arguments elementwise.',
-          TD(nocmplx),
-          TD(cmplx, f='prod'),
+          TD(noobj),
           TD(O, f='PyNumber_Multiply'),
           ),
 'divide' :
     Ufunc(2, 1, One,
           'divides the arguments elementwise.',
-          TD(intflt),
-          TD(cmplx, f='quot'),
+          TD(intfltcmplx),
           TD(O, f='PyNumber_Divide'),
           ),
 'floor_divide' :
     Ufunc(2, 1, One,
           'floor divides the arguments elementwise.',
-          TD(intflt),
-          TD(cmplx, f='floor_quot'),
+          TD(intfltcmplx),
           TD(O, f='PyNumber_FloorDivide'),
           ),
 'true_divide' :
@@ -145,8 +142,7 @@ defdict = {
           'true divides the arguments elementwise.',
           TD('bBhH', out='f'),
           TD('iIlLqQ', out='d'),
-          TD(flts),
-          TD(cmplx, f='quot'),
+          TD(flts+cmplx),
           TD(O, f='PyNumber_TrueDivide'),
           ),
 'conjugate' :
@@ -176,7 +172,7 @@ defdict = {
           ),
 'ones_like' :
     Ufunc(1, 1, None,
-          'return 1',
+          'returns an array of ones of the shape and typecode of x.',
           TD(nobool_or_obj),
           TD(O, f='Py_get_one'),
           ),
@@ -264,11 +260,13 @@ defdict = {
     Ufunc(2, 1, None,
           'returns maximum (if x1 > x2: x1;  else: x2) elementwise.',
           TD(noobj),
+          TD(O, f='_npy_ObjectMax')
           ),
 'minimum' :
     Ufunc(2, 1, None,
           'returns minimum (if x1 < x2: x1;  else: x2) elementwise',
           TD(noobj),
+          TD(O, f='_npy_ObjectMin')
           ),
 'bitwise_and' :
     Ufunc(2, 1, One,
@@ -435,7 +433,7 @@ defdict = {
 'rint' :
     Ufunc(1, 1, None,
           'round x elementwise to the nearest integer, round halfway cases away from zero',
-          TD(flts, f='rint'),
+          TD(inexact, f='rint'),
           TD(M, f='rint'),
           ),
 'arctan2' :
@@ -485,7 +483,7 @@ defdict = {
 
 def indent(st,spaces):
     indention = ' '*spaces
-    indented = indention + string.replace(st,'\n','\n'+indention)
+    indented = indention + st.replace('\n','\n'+indention)
     # trim off any trailing spaces
     indented = re.sub(r' +$',r'',indented)
     return indented
@@ -569,7 +567,11 @@ def make_arrays(funcdict):
                 elif t.type == 'M':
                     datalist.append('(void *)"%s"' % t.func_data)
                 else:
-                    datalist.append('(void *)%s' % t.func_data)
+                    astr = '%s_data[%d] = (void *) %s;' % \
+                           (name, k, t.func_data)
+                    code2list.append(astr)
+                    datalist.append('(void *)NULL')
+                    #datalist.append('(void *)%s' % t.func_data)
                 sub += 1
             else:
                 datalist.append('(void *)NULL');
